/* Tabela TIPOAJPAGAR: */
/* Descrio: A trigger insere registros na tabela LOGOPERA a partir de alteraes na tabela TIPOAJPAGAR */
/* Objetivo: Gerar um log que vai registrar as alteraes na tabela TIPOAJPAGAR
utilizando a tabela Geral de Logs de Operaes */

IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'LOG_GER_TIPOAJPAGAR' AND
                 TYPE = 'TR' 		       AND
	              U.UID = O.UID            AND
	              U.NAME = USER)
DROP TRIGGER LOG_GER_TIPOAJPAGAR
GO

CREATE TRIGGER LOG_GER_TIPOAJPAGAR
ON TIPOAJPAGAR
FOR INSERT, UPDATE, DELETE
AS

  DECLARE @V_DSREMOTEADDR VARCHAR(15);
  DECLARE @V_DSREMOTEHOST VARCHAR(15);
  DECLARE @V_DSSERVERRDM  VARCHAR(20);
  DECLARE @V_DSSERVMETHOD VARCHAR(30);
  DECLARE @V_DSREMOTEOPER VARCHAR(12);
  DECLARE @V_DESC         VARCHAR(500);
  DECLARE @V_ITPESQ       VARCHAR(40);
  DECLARE @V_NMOPERADOR   VARCHAR(40);
  DECLARE @V_IDTIPOOPER   VARCHAR(1);

/*VARIVEIS DO CURSOR C_CURSOR*/

  DECLARE @V_IDCOMANDO      VARCHAR(1);
  DECLARE @V_OLD_CDAJUCTPAG VARCHAR(4);
  DECLARE @V_OLD_CDCONTCTBL VARCHAR(20);
  DECLARE @V_OLD_CDHISTPADR VARCHAR(4);
  DECLARE @V_NEW_CDAJUCTPAG VARCHAR(4);
  DECLARE @V_NEW_CDCONTCTBL VARCHAR(20);
  DECLARE @V_NEW_CDHISTPADR VARCHAR(40);

BEGIN
/* IDTIPOOPER - '1' - Incluso, '2' - Alterao, '3' - Excluso*/
   SET @V_DESC       = '';
   SET @V_ITPESQ     = '';
   SET @V_NMOPERADOR = '';
   SET @V_IDTIPOOPER = '';
   EXEC NMUSUARIO @V_NMOPERADOR;

   EXEC WEBTUNNING @V_DSREMOTEADDR,
              @V_DSREMOTEHOST,
              @V_DSSERVERRDM,
              @V_DSSERVMETHOD,
              @V_DSREMOTEOPER;

   DECLARE C_CURSOR CURSOR FOR
   SELECT
     'D' IDCOMANDO,
         CDAJUCTPAG,
         CDCONTCTBL,
         CDHISTPADR,
         NULL,
         NULL,
         NULL
   FROM
     DELETED
   WHERE
     CDAJUCTPAG+CDCONTCTBL+CDHISTPADR NOT IN (SELECT CDAJUCTPAG+CDCONTCTBL+CDHISTPADR
                                              FROM INSERTED)
   UNION ALL

   SELECT
     'U' IDCOMANDO,
         DELETED.CDAJUCTPAG,
         DELETED.CDCONTCTBL,
         DELETED.CDHISTPADR,
         INSERTED.CDAJUCTPAG,
         INSERTED.CDCONTCTBL,
         INSERTED.CDHISTPADR
   FROM
      INSERTED,
      DELETED
   WHERE
      INSERTED.CDAJUCTPAG     = DELETED.CDAJUCTPAG    AND
      INSERTED.CDCONTCTBL   = DELETED.CDCONTCTBL  AND
      INSERTED.CDHISTPADR    = DELETED.CDHISTPADR
   UNION ALL

   SELECT
     'I' IDCOMANDO,
         NULL,
         NULL,
         NULL,
         CDAJUCTPAG,
         CDCONTCTBL,
         CDHISTPADR
   FROM
      INSERTED
   WHERE
     CDAJUCTPAG+CDCONTCTBL+CDHISTPADR NOT IN (SELECT CDAJUCTPAG+CDCONTCTBL+CDHISTPADR
                                              FROM DELETED)

   OPEN C_CURSOR;
   FETCH NEXT FROM C_CURSOR INTO @V_IDCOMANDO,
				 @V_OLD_CDAJUCTPAG,
				 @V_OLD_CDCONTCTBL,
				 @V_OLD_CDHISTPADR,
				 @V_NEW_CDAJUCTPAG,
				 @V_NEW_CDCONTCTBL,
				 @V_NEW_CDHISTPADR;

   WHILE (@@FETCH_STATUS = 0) BEGIN
      IF @V_IDCOMANDO = 'D' BEGIN
         SET @V_IDTIPOOPER   = '3';
         SET @V_ITPESQ       = @V_OLD_CDAJUCTPAG;
         SET @V_DESC         = 'Cod '       + '' + ISNULL(@V_OLD_CDAJUCTPAG,'')+' '+
                                'ContContabil '  + '' + ISNULL(@V_OLD_CDCONTCTBL,'')+' '+
                                'HistPadr ' + '' + ISNULL(@V_OLD_CDHISTPADR,'');
      END
      ELSE BEGIN
         IF @V_IDCOMANDO = 'U' BEGIN
            SET @V_DESC         = 'Cod '       + '' + ISNULL(@V_NEW_CDAJUCTPAG,'')+' '+
                                   'ContContabil '  + '' + ISNULL(@V_NEW_CDCONTCTBL,'')+' '+
                                   'HistPadr ' + '' + ISNULL(@V_NEW_CDHISTPADR,'');
            SET @V_ITPESQ = @V_NEW_CDAJUCTPAG;
            SET @V_IDTIPOOPER = '2';
         END
         ELSE BEGIN
            SET @V_IDTIPOOPER   = '1';
            SET @V_ITPESQ       = @V_NEW_CDAJUCTPAG;
            SET @V_DESC         = 'Cod '       + '' + ISNULL(@V_NEW_CDAJUCTPAG,'')+' '+
                                   'ContContabil '  + '' + ISNULL(@V_NEW_CDCONTCTBL,'')+' '+
                                   'HistPadr ' + '' + ISNULL(@V_NEW_CDHISTPADR,'');
         END;
      END;
      SET @V_DESC = SUBSTRING(@V_DESC, 1, 300);
      INSERT INTO LOGOPERA
         (NMTABELA,
          DTOPERACAO,
          NMRESPOPER,
          IDTIPOOPER,
          DSOPERACAO,
          CDPESQITEM,
          DSRDMUSUOPER,
          DSENDUSUOPER,
          DSNMUSUOPER,
          DSMETUSUOPER,
          CDORESPOPER)
      VALUES
         ('TIPOAJPAGAR',
          GETDATE(),
          ISNULL(@V_NMOPERADOR,' '),
          @V_IDTIPOOPER,
          @V_DESC,
          @V_ITPESQ,
          @V_DSSERVERRDM,
          @V_DSREMOTEADDR,
          @V_DSREMOTEHOST,
          @V_DSSERVMETHOD,
          @V_DSREMOTEOPER);
      FETCH NEXT FROM C_CURSOR INTO @V_IDCOMANDO,
	   			    @V_OLD_CDAJUCTPAG,
		   		    @V_OLD_CDCONTCTBL,
				    @V_OLD_CDHISTPADR,
				    @V_NEW_CDAJUCTPAG,
				    @V_NEW_CDCONTCTBL,
				    @V_NEW_CDHISTPADR;
   END;
   CLOSE      C_CURSOR;
   DEALLOCATE C_CURSOR;
END;
GO